use crate::database::controller::connector::establish_connection;
use crate::helper::settings::Settings;
use crate::modules::api::members::member_communication::CommunicationTarget;
use crate::schema::communication_targets::dsl::{communication_targets, target_id};
use diesel::query_dsl::filter_dsl::FilterDsl;
use diesel::{ExpressionMethods, RunQueryDsl};
use rocket::State;

/// Updates communication target via API.
/// Will only change field if field is Some, will ignore field if it's None.
///
/// Parameters:
/// * settings: Settings as managed State
/// * com_target_id: uuid of communication target to change
/// * com_target: transmitted CommunicationTarget struct, (all fields optional)
pub fn update_communication_target(
    settings: &State<Settings>,
    com_target_id: uuid::Uuid,
    com_target: CommunicationTarget,
) -> Result<usize, diesel::result::Error> {
    let connection = establish_connection(settings);

    match diesel::update(communication_targets.filter(target_id.eq(com_target_id)))
        .set(&com_target)
        .execute(&connection)
    {
        Ok(affected_rows) => Ok(affected_rows),
        Err(e) => {
            warn!("Couldn't update communication target: {}", e);
            Err(e)
        }
    }
}
