use crate::helper::check_access::check_access_legacy;
use crate::helper::settings::Settings;
use crate::modules::member_management::model::member::Member;
use rocket::State;

/// Checks context for each permission and returns all permissions left
/// Used for permission checking in templates
///
/// Arguments:
/// * <settings>: State with Settings
/// * <caller>: member that requested access to resource
/// * <member_to_check>: member/resource to check if caller has access
pub fn get_permissions_for_context(
    settings: &State<Settings>,
    caller: &Member,
    member_to_check: &Member,
) -> Vec<String> {
    let mut permissions: Vec<String> = vec![];

    for permission in caller.permissions.iter() {
        if check_access_legacy(
            &settings,
            member_to_check,
            caller.entity_id,
            permission.clone(),
        ) {
            permissions.push(permission.clone());
        }
    }
    permissions
}
