use rocket::State;
use crate::helper::settings::Settings;
use crate::helper::session_cookies::model::SessionCookie;
use crate::modules::api::model::api_outcome::{ApiErrorWrapper, ApiError};
use crate::modules::api::member_management::controller::parser::{parse_member_cookie, parse_uuid};
use rocket_contrib::json::Json;
use crate::database::controller::members_groups::add_member_to_group;
use crate::helper::translate_diesel_error::translate_diesel;
use crate::database::controller::members::check_member_has_access;
use crate::modules::member_management::model::groups::{GroupData, GroupUpdateData};
use crate::database::controller::groups::update_group_core_data;

#[put("/api/groups/<group_id>/members/<member_id>", format = "json")]
pub fn put_member_in_group(settings: State<Settings>, cookie: SessionCookie, group_id: String, member_id: String) -> Result<(), Json<ApiErrorWrapper>>{
    let caller = parse_member_cookie(cookie.member)?;
    let member_id = parse_uuid(member_id)?;
    let group_id = parse_uuid(group_id)?;

    if !check_member_has_access(&settings, caller.entity_id, group_id, crate::permissions::modules::member_management::groups::members::EDIT){
        return Err(Json(ApiError::new(403, "Keine Berechtigung Gruppenmitglieder zu ändern!".to_string()).to_wrapper()))
    }

    match add_member_to_group(&settings, member_id, group_id){
        Ok(_) => Ok(()),
        Err(e) => Err(translate_diesel(e))
    }
}

#[put("/api/groups/<group_id>", format = "json", data = "<update_group_data>")]
pub fn update_group(settings: State<Settings>, cookie: SessionCookie, update_group_data: Json<GroupUpdateData>, group_id: String) -> Result<(), Json<ApiErrorWrapper>>{
    let caller = parse_member_cookie(cookie.member)?;
    let group_id = parse_uuid(group_id)?;

    if !check_member_has_access(&settings, caller.entity_id, group_id, crate::permissions::modules::member_management::groups::core::EDIT){
        return Err(Json(ApiError::new(403, "Keine Berechtigung Gruppe zu ändern!".to_string()).to_wrapper()))
    }

    match update_group_core_data(&settings, group_id, update_group_data.into_inner()){
        Ok(_) => Ok(()),
        Err(e) => Err(translate_diesel(e))
    }
}
