use rocket::State;
use crate::helper::settings::Settings;
use crate::helper::session_cookies::model::SessionCookie;
use rocket_contrib::json::Json;
use crate::modules::api::model::api_outcome::{ApiErrorWrapper, ApiError};
use crate::modules::api::member_management::controller::parser::{parse_member_cookie, parse_uuid};
use crate::database::controller::members::check_member_has_access;
use crate::database::controller::units_members::remove_member_from_unit;
use crate::helper::translate_diesel_error::translate_diesel;

#[delete("/api/units/<unit_id>/members/<member_id>", format = "json")]
pub fn delete_member_from_unit(settings: State<Settings>, cookie: SessionCookie, unit_id: String, member_id: String) -> Result<(), Json<ApiErrorWrapper>>{
    let caller = parse_member_cookie(cookie.member)?;
    let member_id = parse_uuid(member_id)?;
    let unit_id = parse_uuid(unit_id)?;

    if !check_member_has_access(&settings, caller.entity_id, unit_id, crate::permissions::modules::units::members::EDIT){
        return Err(Json(ApiError::new(403, "Keine Berechtigung Einheitenmitglieder zu ändern!".to_string()).to_wrapper()))
    }

    match remove_member_from_unit(&settings, member_id, unit_id){
        Ok(_) => Ok(()),
        Err(e) => Err(translate_diesel(e))
    }
}