use crate::helper::session_cookies::model::{SessionCookie, SessionCookieStorage};
use crate::helper::settings::Settings;
use rocket::State;
use rocket::http::Status;
use rocket_contrib::templates::Template;
use crate::database::controller::members::get_member_by_uuid;
use crate::modules::member_management::controller::member_personal_profile::{handle_view, handle_edit};
use crate::database::controller::addresses::get_addresses_for_entity_only_one_allowed;
use crate::database::controller::member_update::update_member;
use rocket::request::Form;
use crate::modules::member_management::model::member::MemberProfileForm;

#[get("/portal/personal_profile?<action>")]
pub fn member_management_personal_profile_get(
    cookie: SessionCookie,
    settings: State<Settings>,
    action: Option<String>,
) -> Result<Template, Status> {
    let caller = match cookie.member {
        //Unwraps member from cookie or send user to login if no member specified (user skipped member selection)
        Some(member) => member,
        None => return Err(Status::Unauthorized),
    };

    match action {
        Some(action) => match action.as_ref() {
            "view" => handle_view(&settings, caller),
            "edit" => handle_edit(&settings, caller),
            _ => return Err(Status::NotFound),
        },
        None => handle_view(&settings, caller),
    }
}

#[post("/portal/personal_profile?<action>", data = "<form>" )]
pub fn member_management_personal_profile_post(
    mut cookie: SessionCookie,
    settings: State<Settings>,
    action: Option<String>,
    form: Form<MemberProfileForm>,
    cookie_storage: State<SessionCookieStorage>,
) -> Result<Template, Status> {
    let caller = match cookie.member {
        //Unwraps member from cookie or send user to login if no member specified (user skipped member selection)
        Some(member) => member,
        None => return Err(Status::Unauthorized),
    };

    let member = match get_member_by_uuid(caller.entity_id, &settings) {
        Some(member) => member,
        None => return Err(Status::NotFound),
    };

    let address = get_addresses_for_entity_only_one_allowed(&settings, caller.entity_id);

    update_member(&settings, form.into_inner(), member.clone(), address, true);

    let member = match get_member_by_uuid(caller.entity_id, &settings) {
        Some(member) => member,
        None => return Err(Status::NotFound),
    };

    cookie.member = Some(member.clone());
    cookie_storage.update(cookie);

    match action {
        Some(action) => match action.as_ref() {
            "view" => handle_view(&settings, member),
            "edit" => handle_edit(&settings, member),
            _ => return Err(Status::NotFound),
        },
        None => handle_view(&settings, caller),
    }
}